#' @import methods
#' @import stats
#' @import utils

setOldClass("lfactor")
setGeneric("match")
setGeneric("%in%")

